from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    path: str,
    access_duration_sec: Union[None, Unset, float] = 3600.0,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    params["path"] = path

    json_access_duration_sec: Union[None, Unset, float]
    if isinstance(access_duration_sec, Unset):
        json_access_duration_sec = UNSET
    else:
        json_access_duration_sec = access_duration_sec
    params["access_duration_sec"] = json_access_duration_sec

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/collection/get_url",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, HTTPValidationError, str]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = cast(str, response.json())
        return response_200
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if response.status_code == HTTPStatus.UNPROCESSABLE_ENTITY:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, HTTPValidationError, str]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    path: str,
    access_duration_sec: Union[None, Unset, float] = 3600.0,
) -> Response[Union[Any, HTTPValidationError, str]]:
    """Get Url

    Args:
        path (str):
        access_duration_sec (Union[None, Unset, float]):  Default: 3600.0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError, str]]
    """

    kwargs = _get_kwargs(
        path=path,
        access_duration_sec=access_duration_sec,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    path: str,
    access_duration_sec: Union[None, Unset, float] = 3600.0,
) -> Optional[Union[Any, HTTPValidationError, str]]:
    """Get Url

    Args:
        path (str):
        access_duration_sec (Union[None, Unset, float]):  Default: 3600.0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError, str]
    """

    return sync_detailed(
        client=client,
        path=path,
        access_duration_sec=access_duration_sec,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    path: str,
    access_duration_sec: Union[None, Unset, float] = 3600.0,
) -> Response[Union[Any, HTTPValidationError, str]]:
    """Get Url

    Args:
        path (str):
        access_duration_sec (Union[None, Unset, float]):  Default: 3600.0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError, str]]
    """

    kwargs = _get_kwargs(
        path=path,
        access_duration_sec=access_duration_sec,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    path: str,
    access_duration_sec: Union[None, Unset, float] = 3600.0,
) -> Optional[Union[Any, HTTPValidationError, str]]:
    """Get Url

    Args:
        path (str):
        access_duration_sec (Union[None, Unset, float]):  Default: 3600.0.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError, str]
    """

    return (
        await asyncio_detailed(
            client=client,
            path=path,
            access_duration_sec=access_duration_sec,
        )
    ).parsed
